@@ -3,7 +3,7 @@
 import re
 from dataclasses import dataclass, field
 from typing import List
-from .utils import is_uri_or_prefixed_uri
+from .utils import coerce_integer, coerce_numeric, is_uri_or_prefixed_uri
 
 
 @dataclass
@@ -37,6 +37,10 @@ class TAPStatementTemplate:
         self._valueConstraintType_iristem_parse()
         self._valueConstraintType_iristem_warn_if_list_items_not_IRIs()
         self._valueConstraintType_languageTag_parse(settings)
+        self._valueConstraintType_minmaxlength_parse()
+        self._valueConstraintType_minmaxlength_warn_if_not_integer()
+        self._valueConstraintType_minmaxinclusive_parse()
+        self._valueConstraintType_minmaxinclusive_warn_if_value_not_numeric()
         self._valueConstraintType_warn_if_used_without_valueConstraint()
         self._valueDataType_warn_if_used_with_valueNodeType_IRI()
         self._valueDataType_warn_if_valueNodeType_literal_used_with_any_valueShape()
@@ -112,6 +116,53 @@ class TAPStatementTemplate:
                     )
         return self
 
+    def _valueConstraintType_minmaxlength_parse(self):
+        """valueConstraintType minLength: coerce integer (or return string)."""
+        self.valueConstraintType = self.valueConstraintType.lower()
+        value_constraint = self.valueConstraint
+        if self.valueConstraintType in ('minlength', 'maxlength'):
+            if value_constraint:
+                self.valueConstraint = coerce_integer(value_constraint)
+        return self
+
+    def _valueConstraintType_minmaxlength_warn_if_not_integer(self):
+        """Warns if valueConstraint minLength not a nonnegative integer."""
+        self.valueConstraintType = self.valueConstraintType.lower()
+        if self.valueConstraintType in ('minlength', 'maxlength'):
+            try:
+                int(self.valueConstraint)
+            except (ValueError, TypeError):
+                self.state_warns["valueConstraint"] = (
+                    f"Value constraint type is {repr(self.valueConstraintType)}, "
+                    f"but {repr(self.valueConstraint)} is not an integer."
+                )
+        return self
+
+    def _valueConstraintType_minmaxinclusive_parse(self):
+        """
+        valueConstraintType minInclusive / maxInclusive
+        - value of valueConstraint should be numeric (int or float)
+        """
+        self.valueConstraintType = self.valueConstraintType.lower()
+        value_constraint = self.valueConstraint
+        if self.valueConstraintType in ("mininclusive", "maxinclusive"):
+            if value_constraint:
+                self.valueConstraint = coerce_numeric(value_constraint)
+        return self
+
+    def _valueConstraintType_minmaxinclusive_warn_if_value_not_numeric(self):
+        """Warns if valueConstraint for minInclusive not coercable to float."""
+        self.valueConstraintType = self.valueConstraintType.lower()
+        if self.valueConstraintType in ("mininclusive", "maxinclusive"):
+            try:
+                float(self.valueConstraint)
+            except (ValueError, TypeError):
+                self.state_warns["valueConstraint"] = (
+                        f"Value constraint type is {repr(self.valueConstraintType)}, "
+                        f"but {repr(self.valueConstraint)} is not numeric."
+                    )
+        return self
+
     def _valueConstraintType_pattern_warn_if_valueConstraint_not_valid_regex(self):
         """If valueConstraintType Pattern, warn if valueConstraint not valid regex."""
         self.valueConstraintType = self.valueConstraintType.lower()
